filter_file: Filter File

Description Usage Arguments Value Examples

Description

A wrapper around the rcpp_filter function. Given a file and a list of words. Remove each occurance of those words from that file. Will modify the input file, so no output file is specified.

Usage

1
filter_file(words, ifilepath)

Arguments

words

A character vector of all the words to remove.

ifilepath

A string specifying the path to the input file.

Value

ifilepath

Examples

1
2
3
4
5
## Not run: 
filter_file(most_common_terms, "/path/to/file.txt")
filter_file(stopwords, "/path/to/file.txt")

## End(Not run)

avkoehl/textprocessingDSI documentation built on June 5, 2019, 7:41 p.m.