rcpp_filter: Rcpp Filter

Description Usage Arguments

Description

Given a vector of words and an input file, search through the file and remove all instances of that word. Overwrites the input file with the modified content.

Usage

1
rcpp_filter(words, ifilename)

Arguments

words

A string vector containing the list of words to be removed from the file.

ifilename

A string containing the path to the inputfile> Returns the name of the file that was modified.


avkoehl/textprocessingDSI documentation built on June 5, 2019, 7:41 p.m.