Description Usage Arguments Value Examples
A wrapper around the rcpp_filter function. Given a file and a list of words. Remove each occurance of those words from that file. Will modify the input file, so no output file is specified.
1 | filter_file(words, ifilepath)
|
words |
A character vector of all the words to remove. |
ifilepath |
A string specifying the path to the input file. |
ifilepath
1 2 3 4 5 | ## Not run:
filter_file(most_common_terms, "/path/to/file.txt")
filter_file(stopwords, "/path/to/file.txt")
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.