Given a vector of words and an input file, search through the file and remove all instances of that word. Overwrites the input file with the modified content.
1 | rcpp_filter(words, ifilename)
|
words |
A string vector containing the list of words to be removed from the file. |
ifilename |
A string containing the path to the inputfile> Returns the name of the file that was modified. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.